@@ -1,4 +1,4 @@
-"Fanout cache automatically shards keys and values."
+"""Fanout cache automatically shards keys and values."""
 
 import contextlib as cl
 import functools
@@ -9,14 +9,16 @@ import sqlite3
 import tempfile
 import time
 
-from .core import ENOVAL, DEFAULT_SETTINGS, Cache, Disk, Timeout
+from .core import DEFAULT_SETTINGS, ENOVAL, Cache, Disk, Timeout
 from .persistent import Deque, Index
 
 
-class FanoutCache(object):
-    "Cache that shards keys and values."
-    def __init__(self, directory=None, shards=8, timeout=0.010, disk=Disk,
-                 **settings):
+class FanoutCache:
+    """Cache that shards keys and values."""
+
+    def __init__(
+        self, directory=None, shards=8, timeout=0.010, disk=Disk, **settings
+    ):
         """Initialize cache instance.
 
         :param str directory: cache directory
@@ -28,6 +30,7 @@ class FanoutCache(object):
         """
         if directory is None:
             directory = tempfile.mkdtemp(prefix='diskcache-')
+        directory = str(directory)
         directory = op.expanduser(directory)
         directory = op.expandvars(directory)
 
@@ -36,13 +39,14 @@ class FanoutCache(object):
 
         self._count = shards
         self._directory = directory
+        self._disk = disk
         self._shards = tuple(
             Cache(
                 directory=op.join(directory, '%03d' % num),
                 timeout=timeout,
                 disk=disk,
                 size_limit=size_limit,
-                **settings
+                **settings,
             )
             for num in range(shards)
         )
@@ -51,20 +55,17 @@ class FanoutCache(object):
         self._deques = {}
         self._indexes = {}
 
-
     @property
     def directory(self):
         """Cache directory."""
         return self._directory
 
-
     def __getattr__(self, name):
         safe_names = {'timeout', 'disk'}
         valid_name = name in DEFAULT_SETTINGS or name in safe_names
         assert valid_name, 'cannot access {} in cache shard'.format(name)
         return getattr(self._shards[0], name)
 
-
     @cl.contextmanager
     def transact(self, retry=True):
         """Context manager to perform a transaction by locking the cache.
@@ -98,7 +99,6 @@ class FanoutCache(object):
                 stack.enter_context(shard_transaction)
             yield
 
-
     def set(self, key, value, expire=None, read=False, tag=None, retry=False):
         """Set `key` and `value` item in cache.
 
@@ -125,7 +125,6 @@ class FanoutCache(object):
         except Timeout:
             return False
 
-
     def __setitem__(self, key, value):
         """Set `key` and `value` item in cache.
 
@@ -139,7 +138,6 @@ class FanoutCache(object):
         shard = self._shards[index]
         shard[key] = value
 
-
     def touch(self, key, expire=None, retry=False):
         """Touch `key` in cache and update `expire` time.
 
@@ -160,7 +158,6 @@ class FanoutCache(object):
         except Timeout:
             return False
 
-
     def add(self, key, value, expire=None, read=False, tag=None, retry=False):
         """Add `key` and `value` item to cache.
 
@@ -192,7 +189,6 @@ class FanoutCache(object):
         except Timeout:
             return False
 
-
     def incr(self, key, delta=1, default=0, retry=False):
         """Increment value by delta for item with key.
 
@@ -224,7 +220,6 @@ class FanoutCache(object):
         except Timeout:
             return None
 
-
     def decr(self, key, delta=1, default=0, retry=False):
         """Decrement value by delta for item with key.
 
@@ -259,9 +254,15 @@ class FanoutCache(object):
         except Timeout:
             return None
 
-
-    def get(self, key, default=None, read=False, expire_time=False, tag=False,
-            retry=False):
+    def get(
+        self,
+        key,
+        default=None,
+        read=False,
+        expire_time=False,
+        tag=False,
+        retry=False,
+    ):
         """Retrieve value from cache. If `key` is missing, return `default`.
 
         If database timeout occurs then returns `default` unless `retry` is set
@@ -285,7 +286,6 @@ class FanoutCache(object):
         except (Timeout, sqlite3.OperationalError):
             return default
 
-
     def __getitem__(self, key):
         """Return corresponding value for `key` from cache.
 
@@ -300,7 +300,6 @@ class FanoutCache(object):
         shard = self._shards[index]
         return shard[key]
 
-
     def read(self, key):
         """Return file handle corresponding to `key` from cache.
 
@@ -314,7 +313,6 @@ class FanoutCache(object):
             raise KeyError(key)
         return handle
 
-
     def __contains__(self, key):
         """Return `True` if `key` matching item is found in cache.
 
@@ -326,8 +324,9 @@ class FanoutCache(object):
         shard = self._shards[index]
         return key in shard
 
-
-    def pop(self, key, default=None, expire_time=False, tag=False, retry=False):  # noqa: E501
+    def pop(
+        self, key, default=None, expire_time=False, tag=False, retry=False
+    ):  # noqa: E501
         """Remove corresponding item for `key` from cache and return value.
 
         If `key` is missing, return `default`.
@@ -353,7 +352,6 @@ class FanoutCache(object):
         except Timeout:
             return default
 
-
     def delete(self, key, retry=False):
         """Delete corresponding item for `key` from cache.
 
@@ -374,7 +372,6 @@ class FanoutCache(object):
         except Timeout:
             return False
 
-
     def __delitem__(self, key):
         """Delete corresponding item for `key` from cache.
 
@@ -388,7 +385,6 @@ class FanoutCache(object):
         shard = self._shards[index]
         del shard[key]
 
-
     def check(self, fix=False, retry=False):
         """Check database and file system consistency.
 
@@ -412,7 +408,6 @@ class FanoutCache(object):
         warnings = (shard.check(fix, retry) for shard in self._shards)
         return functools.reduce(operator.iadd, warnings, [])
 
-
     def expire(self, retry=False):
         """Remove expired items from cache.
 
@@ -425,7 +420,6 @@ class FanoutCache(object):
         """
         return self._remove('expire', args=(time.time(),), retry=retry)
 
-
     def create_tag_index(self):
         """Create tag index on cache database.
 
@@ -437,7 +431,6 @@ class FanoutCache(object):
         for shard in self._shards:
             shard.create_tag_index()
 
-
     def drop_tag_index(self):
         """Drop tag index on cache database.
 
@@ -447,7 +440,6 @@ class FanoutCache(object):
         for shard in self._shards:
             shard.drop_tag_index()
 
-
     def evict(self, tag, retry=False):
         """Remove items with matching `tag` from cache.
 
@@ -461,7 +453,6 @@ class FanoutCache(object):
         """
         return self._remove('evict', args=(tag,), retry=retry)
 
-
     def cull(self, retry=False):
         """Cull items from cache until volume is less than size limit.
 
@@ -474,7 +465,6 @@ class FanoutCache(object):
         """
         return self._remove('cull', retry=retry)
 
-
     def clear(self, retry=False):
         """Remove all items from cache.
 
@@ -487,7 +477,6 @@ class FanoutCache(object):
         """
         return self._remove('clear', retry=retry)
 
-
     def _remove(self, name, args=(), retry=False):
         total = 0
         for shard in self._shards:
@@ -502,7 +491,6 @@ class FanoutCache(object):
                     break
         return total
 
-
     def stats(self, enable=True, reset=False):
         """Return cache statistics hits and misses.
 
@@ -516,7 +504,6 @@ class FanoutCache(object):
         total_misses = sum(misses for _, misses in results)
         return total_hits, total_misses
 
-
     def volume(self):
         """Return estimated total size of cache on disk.
 
@@ -525,49 +512,40 @@ class FanoutCache(object):
         """
         return sum(shard.volume() for shard in self._shards)
 
-
     def close(self):
-        "Close database connection."
+        """Close database connection."""
         for shard in self._shards:
             shard.close()
         self._caches.clear()
         self._deques.clear()
         self._indexes.clear()
 
-
     def __enter__(self):
         return self
 
-
     def __exit__(self, *exception):
         self.close()
 
-
     def __getstate__(self):
         return (self._directory, self._count, self.timeout, type(self.disk))
 
-
     def __setstate__(self, state):
         self.__init__(*state)
 
-
     def __iter__(self):
-        "Iterate keys in cache including expired items."
+        """Iterate keys in cache including expired items."""
         iterators = (iter(shard) for shard in self._shards)
         return it.chain.from_iterable(iterators)
 
-
     def __reversed__(self):
-        "Reverse iterate keys in cache including expired items."
+        """Reverse iterate keys in cache including expired items."""
         iterators = (reversed(shard) for shard in reversed(self._shards))
         return it.chain.from_iterable(iterators)
 
-
     def __len__(self):
-        "Count of items in cache including expired items."
+        """Count of items in cache including expired items."""
         return sum(len(shard) for shard in self._shards)
 
-
     def reset(self, key, value=ENOVAL):
         """Reset `key` and `value` item from Settings table.
 
@@ -596,10 +574,11 @@ class FanoutCache(object):
                     break
         return result
 
-
-    def cache(self, name):
+    def cache(self, name, timeout=60, disk=None, **settings):
         """Return Cache with given `name` in subdirectory.
 
+        If disk is none (default), uses the fanout cache disk.
+
         >>> fanout_cache = FanoutCache()
         >>> cache = fanout_cache.cache('test')
         >>> cache.set('abc', 123)
@@ -612,6 +591,9 @@ class FanoutCache(object):
         True
 
         :param str name: subdirectory name for Cache
+        :param float timeout: SQLite connection timeout
+        :param disk: Disk type or subclass for serialization
+        :param settings: any of DEFAULT_SETTINGS
         :return: Cache with given name
 
         """
@@ -622,12 +604,16 @@ class FanoutCache(object):
         except KeyError:
             parts = name.split('/')
             directory = op.join(self._directory, 'cache', *parts)
-            temp = Cache(directory=directory)
+            temp = Cache(
+                directory=directory,
+                timeout=timeout,
+                disk=self._disk if disk is None else Disk,
+                **settings,
+            )
             _caches[name] = temp
             return temp
 
-
-    def deque(self, name):
+    def deque(self, name, maxlen=None):
         """Return Deque with given `name` in subdirectory.
 
         >>> cache = FanoutCache()
@@ -641,6 +627,7 @@ class FanoutCache(object):
         1
 
         :param str name: subdirectory name for Deque
+        :param maxlen: max length (default None, no max)
         :return: Deque with given name
 
         """
@@ -651,10 +638,14 @@ class FanoutCache(object):
         except KeyError:
             parts = name.split('/')
             directory = op.join(self._directory, 'deque', *parts)
-            temp = Deque(directory=directory)
-            _deques[name] = temp
-            return temp
-
+            cache = Cache(
+                directory=directory,
+                disk=self._disk,
+                eviction_policy='none',
+            )
+            deque = Deque.fromcache(cache, maxlen=maxlen)
+            _deques[name] = deque
+            return deque
 
     def index(self, name):
         """Return Index with given `name` in subdirectory.
@@ -683,9 +674,14 @@ class FanoutCache(object):
         except KeyError:
             parts = name.split('/')
             directory = op.join(self._directory, 'index', *parts)
-            temp = Index(directory)
-            _indexes[name] = temp
-            return temp
+            cache = Cache(
+                directory=directory,
+                disk=self._disk,
+                eviction_policy='none',
+            )
+            index = Index.fromcache(cache)
+            _indexes[name] = index
+            return index
 
 
-FanoutCache.memoize = Cache.memoize
+FanoutCache.memoize = Cache.memoize  # type: ignore
