@@ -5,6 +5,7 @@ import hashlib
 import io
 import os
 import os.path as op
+import pathlib
 import pickle
 import shutil
 import sqlite3
@@ -37,12 +38,19 @@ def test_init(cache):
     cache.close()
 
 
+def test_init_path(cache):
+    path = pathlib.Path(cache.directory)
+    other = dc.Cache(path)
+    other.close()
+    assert cache.directory == other.directory
+
+
 def test_init_disk():
-    with dc.Cache(disk_pickle_protocol=1, disk_min_file_size=2 ** 20) as cache:
+    with dc.Cache(disk_pickle_protocol=1, disk_min_file_size=2**20) as cache:
         key = (None, 0, 'abc')
         cache[key] = 0
         cache.check()
-        assert cache.disk_min_file_size == 2 ** 20
+        assert cache.disk_min_file_size == 2**20
         assert cache.disk_pickle_protocol == 1
     shutil.rmtree(cache.directory, ignore_errors=True)
 
@@ -59,15 +67,15 @@ def test_disk_reset():
         assert cache._disk.min_file_size == 0
         assert cache._disk.pickle_protocol == 0
 
-        cache.reset('disk_min_file_size', 2 ** 10)
+        cache.reset('disk_min_file_size', 2**10)
         cache.reset('disk_pickle_protocol', 2)
 
         cache[1] = value
         cache.check()
 
-        assert cache.disk_min_file_size == 2 ** 10
+        assert cache.disk_min_file_size == 2**10
         assert cache.disk_pickle_protocol == 2
-        assert cache._disk.min_file_size == 2 ** 10
+        assert cache._disk.min_file_size == 2**10
         assert cache._disk.pickle_protocol == 2
 
     shutil.rmtree(cache.directory, ignore_errors=True)
@@ -150,7 +158,7 @@ def test_pragma_error(cache):
     cursor.fetchall = fetchall
     fetchall.side_effect = [sqlite3.OperationalError] * 60000
 
-    size = 2 ** 28
+    size = 2**28
 
     with mock.patch('time.sleep', lambda num: 0):
         with mock.patch.object(cache, '_local', local):
@@ -177,15 +185,15 @@ def test_close_error(cache):
 def test_getsetdel(cache):
     values = [
         (None, False),
-        ((None,) * 2 ** 20, False),
+        ((None,) * 2**20, False),
         (1234, False),
-        (2 ** 512, False),
+        (2**512, False),
         (56.78, False),
-        (u'hello', False),
-        (u'hello' * 2 ** 20, False),
+        ('hello', False),
+        ('hello' * 2**20, False),
         (b'world', False),
-        (b'world' * 2 ** 20, False),
-        (io.BytesIO(b'world' * 2 ** 20), True),
+        (b'world' * 2**20, False),
+        (io.BytesIO(b'world' * 2**20), True),
     ]
 
     for key, (value, file_like) in enumerate(values):
@@ -229,7 +237,7 @@ def test_get_keyerror4(cache):
     func = mock.Mock(side_effect=IOError(errno.ENOENT, ''))
 
     cache.reset('statistics', True)
-    cache[0] = b'abcd' * 2 ** 20
+    cache[0] = b'abcd' * 2**20
 
     with mock.patch('diskcache.core.open', func):
         with pytest.raises((IOError, KeyError, OSError)):
@@ -237,7 +245,7 @@ def test_get_keyerror4(cache):
 
 
 def test_read(cache):
-    cache.set(0, b'abcd' * 2 ** 20)
+    cache.set(0, b'abcd' * 2**20)
     with cache.read(0) as reader:
         assert reader is not None
 
@@ -249,7 +257,7 @@ def test_read_keyerror(cache):
 
 
 def test_set_twice(cache):
-    large_value = b'abcd' * 2 ** 20
+    large_value = b'abcd' * 2**20
 
     cache[0] = 0
     cache[0] = 1
@@ -283,7 +291,7 @@ def test_set_timeout(cache):
     with pytest.raises(dc.Timeout):
         try:
             with mock.patch.object(cache, '_local', local):
-                cache.set('a', 'b' * 2 ** 20)
+                cache.set('a', 'b' * 2**20)
         finally:
             cache.check()
 
@@ -299,11 +307,11 @@ def test_get(cache):
     assert cache.get(2, {}) == {}
     assert cache.get(0, expire_time=True, tag=True) == (None, None, None)
 
-    assert cache.set(0, 0, expire=None, tag=u'number')
+    assert cache.set(0, 0, expire=None, tag='number')
 
     assert cache.get(0, expire_time=True) == (0, None)
-    assert cache.get(0, tag=True) == (0, u'number')
-    assert cache.get(0, expire_time=True, tag=True) == (0, None, u'number')
+    assert cache.get(0, tag=True) == (0, 'number')
+    assert cache.get(0, expire_time=True, tag=True) == (0, None, 'number')
 
 
 def test_get_expired_fast_path(cache):
@@ -359,8 +367,8 @@ def test_pop(cache):
     assert cache.set('delta', 210)
     assert cache.pop('delta', expire_time=True) == (210, None)
 
-    assert cache.set('epsilon', '0' * 2 ** 20)
-    assert cache.pop('epsilon') == '0' * 2 ** 20
+    assert cache.set('epsilon', '0' * 2**20)
+    assert cache.pop('epsilon') == '0' * 2**20
 
 
 def test_pop_ioerror(cache):
@@ -426,11 +434,11 @@ def test_stats(cache):
 
 
 def test_path(cache):
-    cache[0] = u'abc'
-    large_value = b'abc' * 2 ** 20
+    cache[0] = 'abc'
+    large_value = b'abc' * 2**20
     cache[1] = large_value
 
-    assert cache.get(0, read=True) == u'abc'
+    assert cache.get(0, read=True) == 'abc'
 
     with cache.get(1, read=True) as reader:
         assert reader.name is not None
@@ -465,7 +473,7 @@ def test_expire_rows(cache):
 
 
 def test_least_recently_stored(cache):
-    cache.reset('eviction_policy', u'least-recently-stored')
+    cache.reset('eviction_policy', 'least-recently-stored')
     cache.reset('size_limit', int(10.1e6))
     cache.reset('cull_limit', 2)
 
@@ -500,7 +508,7 @@ def test_least_recently_stored(cache):
 
 
 def test_least_recently_used(cache):
-    cache.reset('eviction_policy', u'least-recently-used')
+    cache.reset('eviction_policy', 'least-recently-used')
     cache.reset('size_limit', int(10.1e6))
     cache.reset('cull_limit', 5)
 
@@ -530,7 +538,7 @@ def test_least_recently_used(cache):
 
 
 def test_least_frequently_used(cache):
-    cache.reset('eviction_policy', u'least-frequently-used')
+    cache.reset('eviction_policy', 'least-frequently-used')
     cache.reset('size_limit', int(10.1e6))
     cache.reset('cull_limit', 5)
 
@@ -558,8 +566,8 @@ def test_least_frequently_used(cache):
 
 
 def test_check(cache):
-    blob = b'a' * 2 ** 20
-    keys = (0, 1, 1234, 56.78, u'hello', b'world', None)
+    blob = b'a' * 2**20
+    keys = (0, 1, 1234, 56.78, 'hello', b'world', None)
 
     for key in keys:
         cache[key] = blob
@@ -662,12 +670,12 @@ def test_clear_timeout(cache):
 
 
 def test_tag(cache):
-    assert cache.set(0, None, tag=u'zero')
+    assert cache.set(0, None, tag='zero')
     assert cache.set(1, None, tag=1234)
     assert cache.set(2, None, tag=5.67)
     assert cache.set(3, None, tag=b'three')
 
-    assert cache.get(0, tag=True) == (None, u'zero')
+    assert cache.get(0, tag=True) == (None, 'zero')
     assert cache.get(1, tag=True) == (None, 1234)
     assert cache.get(2, tag=True) == (None, 5.67)
     assert cache.get(3, tag=True) == (None, b'three')
@@ -675,11 +683,11 @@ def test_tag(cache):
 
 def test_with(cache):
     with dc.Cache(cache.directory) as tmp:
-        tmp[u'a'] = 0
-        tmp[u'b'] = 1
+        tmp['a'] = 0
+        tmp['b'] = 1
 
-    assert cache[u'a'] == 0
-    assert cache[u'b'] == 1
+    assert cache['a'] == 0
+    assert cache['b'] == 1
 
 
 def test_contains(cache):
@@ -708,7 +716,7 @@ def test_add(cache):
 
 
 def test_add_large_value(cache):
-    value = b'abcd' * 2 ** 20
+    value = b'abcd' * 2**20
     assert cache.add(b'test-key', value)
     assert cache.get(b'test-key') == value
     assert not cache.add(b'test-key', value * 2)
@@ -919,7 +927,7 @@ def test_push_peek_expire(cache):
 
 
 def test_push_pull_large_value(cache):
-    value = b'test' * (2 ** 20)
+    value = b'test' * (2**20)
     cache.push(value)
     assert cache.pull() == (500000000000000, value)
     assert len(cache) == 0
@@ -927,7 +935,7 @@ def test_push_pull_large_value(cache):
 
 
 def test_push_peek_large_value(cache):
-    value = b'test' * (2 ** 20)
+    value = b'test' * (2**20)
     cache.push(value)
     assert cache.peek() == (500000000000000, value)
     assert len(cache) == 1
@@ -1144,8 +1152,8 @@ def test_cull_timeout(cache):
 
 
 def test_key_roundtrip(cache):
-    key_part_0 = u'part0'
-    key_part_1 = u'part1'
+    key_part_0 = 'part0'
+    key_part_1 = 'part1'
     to_test = [
         (key_part_0, key_part_1),
         [key_part_0, key_part_1],
@@ -1354,7 +1362,7 @@ def test_memoize_kwargs(cache):
 
 
 def test_cleanup_dirs(cache):
-    value = b'\0' * 2 ** 20
+    value = b'\0' * 2**20
     start_count = len(os.listdir(cache.directory))
     for i in range(10):
         cache[i] = value
@@ -1370,7 +1378,7 @@ def test_disk_write_os_error(cache):
     func = mock.Mock(side_effect=[OSError] * 10)
     with mock.patch('diskcache.core.open', func):
         with pytest.raises(OSError):
-            cache[0] = '\0' * 2 ** 20
+            cache[0] = '\0' * 2**20
 
 
 def test_memoize_ignore(cache):
