@@ -870,7 +870,6 @@ class BaseCacheTests:
 
     def test_cache_write_unpicklable_object(self):
         fetch_middleware = FetchFromCacheMiddleware(empty_response)
-        fetch_middleware.cache = cache
 
         request = self.factory.get('/cache/test')
         request._cache_update_cache = True
@@ -887,7 +886,6 @@ class BaseCacheTests:
             return response
 
         update_middleware = UpdateCacheMiddleware(get_response)
-        update_middleware.cache = cache
         response = update_middleware(request)
 
         get_cache_data = fetch_middleware.process_request(request)
@@ -1033,7 +1031,7 @@ class DiskCacheTests(BaseCacheTests, TestCase):
         self.assertTrue('tmp' in cache.directory)
 
     def test_read(self):
-        value = b'abcd' * 2 ** 20
+        value = b'abcd' * 2**20
         result = cache.set(b'test-key', value)
 
         self.assertTrue(result)
